"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_KeyVault(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAULTS_FIELD_NUMBER: builtins.int
    VAULTS_ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    VAULTS_KEYS_FIELD_NUMBER: builtins.int
    VAULTS_SECRETS_FIELD_NUMBER: builtins.int
    VAULTS_CERTIFICATES_FIELD_NUMBER: builtins.int
    @property
    def vaults(self) -> global___Vaults: ...
    @property
    def vaults_access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsAccessPolicies]: ...
    @property
    def vaults_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsKeys]: ...
    @property
    def vaults_secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsSecrets]: ...
    @property
    def vaults_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsCertificates]: ...
    def __init__(
        self,
        *,
        vaults: global___Vaults | None = ...,
        vaults_access_policies: collections.abc.Iterable[global___VaultsAccessPolicies] | None = ...,
        vaults_keys: collections.abc.Iterable[global___VaultsKeys] | None = ...,
        vaults_secrets: collections.abc.Iterable[global___VaultsSecrets] | None = ...,
        vaults_certificates: collections.abc.Iterable[global___VaultsCertificates] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vaults", b"vaults"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vaults", b"vaults", "vaults_access_policies", b"vaults_access_policies", "vaults_certificates", b"vaults_certificates", "vaults_keys", b"vaults_keys", "vaults_secrets", b"vaults_secrets"]) -> None: ...

global___Microsoft_KeyVault = Microsoft_KeyVault

@typing_extensions.final
class VaultsCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KEY_VAULT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    key_vault_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        key_vault_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_id", b"key_vault_id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VaultsCertificates = VaultsCertificates

@typing_extensions.final
class VaultsSecrets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def attributes(self) -> global___SecretAttributes: ...
    content_type: builtins.str
    value: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        attributes: global___SecretAttributes | None = ...,
        content_type: builtins.str = ...,
        value: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "content_type", b"content_type", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "value", b"value"]) -> None: ...

global___VaultsSecrets = VaultsSecrets

@typing_extensions.final
class SecretAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    NBF_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    exp: builtins.str
    nbf: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        exp: builtins.str = ...,
        nbf: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "exp", b"exp", "nbf", b"nbf"]) -> None: ...

global___SecretAttributes = SecretAttributes

@typing_extensions.final
class VaultsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___VaultsPrivateEndpointConnections = VaultsPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class VaultsKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    CURVE_NAME_FIELD_NUMBER: builtins.int
    KEY_OPS_FIELD_NUMBER: builtins.int
    KEY_SIZE_FIELD_NUMBER: builtins.int
    KTY_FIELD_NUMBER: builtins.int
    RELEASE_POLICY_FIELD_NUMBER: builtins.int
    ROTATION_POLICY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def attributes(self) -> global___KeyAttributes: ...
    curve_name: builtins.str
    @property
    def key_ops(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key_size: builtins.int
    kty: builtins.str
    @property
    def release_policy(self) -> global___KeyReleasePolicy: ...
    @property
    def rotation_policy(self) -> global___RotationPolicy: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        attributes: global___KeyAttributes | None = ...,
        curve_name: builtins.str = ...,
        key_ops: collections.abc.Iterable[builtins.str] | None = ...,
        key_size: builtins.int = ...,
        kty: builtins.str = ...,
        release_policy: global___KeyReleasePolicy | None = ...,
        rotation_policy: global___RotationPolicy | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "release_policy", b"release_policy", "resource_info", b"resource_info", "rotation_policy", b"rotation_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "curve_name", b"curve_name", "key_ops", b"key_ops", "key_size", b"key_size", "kty", b"kty", "name", b"name", "release_policy", b"release_policy", "resource_info", b"resource_info", "rotation_policy", b"rotation_policy", "tags", b"tags"]) -> None: ...

global___VaultsKeys = VaultsKeys

@typing_extensions.final
class RotationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTRIBUTES_FIELD_NUMBER: builtins.int
    LIFETIME_ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def attributes(self) -> global___KeyRotationPolicyAttributes: ...
    @property
    def lifetime_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifetimeAction]: ...
    def __init__(
        self,
        *,
        attributes: global___KeyRotationPolicyAttributes | None = ...,
        lifetime_actions: collections.abc.Iterable[global___LifetimeAction] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attributes", b"attributes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "lifetime_actions", b"lifetime_actions"]) -> None: ...

global___RotationPolicy = RotationPolicy

@typing_extensions.final
class LifetimeAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def action(self) -> global___Action: ...
    @property
    def trigger(self) -> global___Trigger: ...
    def __init__(
        self,
        *,
        action: global___Action | None = ...,
        trigger: global___Trigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "trigger", b"trigger"]) -> None: ...

global___LifetimeAction = LifetimeAction

@typing_extensions.final
class Trigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_AFTER_CREATE_FIELD_NUMBER: builtins.int
    TIME_BEFORE_EXPIRY_FIELD_NUMBER: builtins.int
    time_after_create: builtins.str
    time_before_expiry: builtins.str
    def __init__(
        self,
        *,
        time_after_create: builtins.str = ...,
        time_before_expiry: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["time_after_create", b"time_after_create", "time_before_expiry", b"time_before_expiry"]) -> None: ...

global___Trigger = Trigger

@typing_extensions.final
class Action(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___Action = Action

@typing_extensions.final
class KeyRotationPolicyAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRY_TIME_FIELD_NUMBER: builtins.int
    expiry_time: builtins.str
    def __init__(
        self,
        *,
        expiry_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiry_time", b"expiry_time"]) -> None: ...

global___KeyRotationPolicyAttributes = KeyRotationPolicyAttributes

@typing_extensions.final
class KeyReleasePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    content_type: builtins.str
    data: builtins.str
    def __init__(
        self,
        *,
        content_type: builtins.str = ...,
        data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "data", b"data"]) -> None: ...

global___KeyReleasePolicy = KeyReleasePolicy

@typing_extensions.final
class KeyAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    EXPORTABLE_FIELD_NUMBER: builtins.int
    NBF_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    exp: builtins.str
    exportable: builtins.bool
    nbf: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        exp: builtins.str = ...,
        exportable: builtins.bool = ...,
        nbf: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "exp", b"exp", "exportable", b"exportable", "nbf", b"nbf"]) -> None: ...

global___KeyAttributes = KeyAttributes

@typing_extensions.final
class VaultsAccessPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessPolicyEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        access_policies: collections.abc.Iterable[global___AccessPolicyEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VaultsAccessPolicies = VaultsAccessPolicies

@typing_extensions.final
class Vaults(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    ENABLED_FOR_DEPLOYMENT_FIELD_NUMBER: builtins.int
    ENABLED_FOR_DISK_ENCRYPTION_FIELD_NUMBER: builtins.int
    ENABLED_FOR_TEMPLATE_DEPLOYMENT_FIELD_NUMBER: builtins.int
    ENABLE_PURGE_PROTECTION_FIELD_NUMBER: builtins.int
    ENABLE_RBAC_AUTHORIZATION_FIELD_NUMBER: builtins.int
    ENABLE_SOFT_DELETE_FIELD_NUMBER: builtins.int
    NETWORK_ACLS_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    SOFT_DELETE_RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    VAULT_URI_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VAULTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessPolicyEntry]: ...
    create_mode: builtins.str
    enabled_for_deployment: builtins.bool
    enabled_for_disk_encryption: builtins.bool
    enabled_for_template_deployment: builtins.bool
    enable_purge_protection: builtins.bool
    enable_rbac_authorization: builtins.bool
    enable_soft_delete: builtins.bool
    @property
    def network_acls(self) -> global___NetworkRuleSet: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    soft_delete_retention_in_days: builtins.int
    tenant_id: builtins.str
    vault_uri: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vaults_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        access_policies: collections.abc.Iterable[global___AccessPolicyEntry] | None = ...,
        create_mode: builtins.str = ...,
        enabled_for_deployment: builtins.bool = ...,
        enabled_for_disk_encryption: builtins.bool = ...,
        enabled_for_template_deployment: builtins.bool = ...,
        enable_purge_protection: builtins.bool = ...,
        enable_rbac_authorization: builtins.bool = ...,
        enable_soft_delete: builtins.bool = ...,
        network_acls: global___NetworkRuleSet | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        sku: global___Sku | None = ...,
        soft_delete_retention_in_days: builtins.int = ...,
        tenant_id: builtins.str = ...,
        vault_uri: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vaults_private_endpoint_connections: collections.abc.Iterable[global___VaultsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_acls", b"network_acls", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "create_mode", b"create_mode", "enable_purge_protection", b"enable_purge_protection", "enable_rbac_authorization", b"enable_rbac_authorization", "enable_soft_delete", b"enable_soft_delete", "enabled_for_deployment", b"enabled_for_deployment", "enabled_for_disk_encryption", b"enabled_for_disk_encryption", "enabled_for_template_deployment", b"enabled_for_template_deployment", "location", b"location", "name", b"name", "network_acls", b"network_acls", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "sku", b"sku", "soft_delete_retention_in_days", b"soft_delete_retention_in_days", "tags", b"tags", "tenant_id", b"tenant_id", "vault_uri", b"vault_uri", "vaults_private_endpoint_connections", b"vaults_private_endpoint_connections"]) -> None: ...

global___Vaults = Vaults

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    family: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        family: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["family", b"family", "name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class NetworkRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYPASS_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    bypass: builtins.str
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPRule]: ...
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworkRule]: ...
    def __init__(
        self,
        *,
        bypass: builtins.str = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___IPRule] | None = ...,
        virtual_network_rules: collections.abc.Iterable[global___VirtualNetworkRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass", b"bypass", "default_action", b"default_action", "ip_rules", b"ip_rules", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___NetworkRuleSet = NetworkRuleSet

@typing_extensions.final
class VirtualNetworkRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IGNORE_MISSING_VNET_SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    id: builtins.str
    ignore_missing_vnet_service_endpoint: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        ignore_missing_vnet_service_endpoint: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "ignore_missing_vnet_service_endpoint", b"ignore_missing_vnet_service_endpoint"]) -> None: ...

global___VirtualNetworkRule = VirtualNetworkRule

@typing_extensions.final
class IPRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___IPRule = IPRule

@typing_extensions.final
class AccessPolicyEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    object_id: builtins.str
    @property
    def permissions(self) -> global___Permissions: ...
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        object_id: builtins.str = ...,
        permissions: global___Permissions | None = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["permissions", b"permissions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "object_id", b"object_id", "permissions", b"permissions", "tenant_id", b"tenant_id"]) -> None: ...

global___AccessPolicyEntry = AccessPolicyEntry

@typing_extensions.final
class Permissions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    STORAGE_FIELD_NUMBER: builtins.int
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def storage(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[builtins.str] | None = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
        secrets: collections.abc.Iterable[builtins.str] | None = ...,
        storage: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificates", b"certificates", "keys", b"keys", "secrets", b"secrets", "storage", b"storage"]) -> None: ...

global___Permissions = Permissions

@typing_extensions.final
class ManagedHSMsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def private_endpoint(self) -> global___MHSMPrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___MHSMPrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    @property
    def sku(self) -> global___ManagedHsmSku: ...
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        private_endpoint: global___MHSMPrivateEndpoint | None = ...,
        private_link_service_connection_state: global___MHSMPrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
        sku: global___ManagedHsmSku | None = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info", "sku", b"sku", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "location", b"location", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "sku", b"sku", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___ManagedHSMsPrivateEndpointConnections = ManagedHSMsPrivateEndpointConnections

@typing_extensions.final
class MHSMPrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___MHSMPrivateLinkServiceConnectionState = MHSMPrivateLinkServiceConnectionState

@typing_extensions.final
class MHSMPrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___MHSMPrivateEndpoint = MHSMPrivateEndpoint

@typing_extensions.final
class ManagedHSMs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    ENABLE_PURGE_PROTECTION_FIELD_NUMBER: builtins.int
    ENABLE_SOFT_DELETE_FIELD_NUMBER: builtins.int
    INITIAL_ADMIN_OBJECT_IDS_FIELD_NUMBER: builtins.int
    NETWORK_ACLS_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SOFT_DELETE_RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_H_S_MS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    create_mode: builtins.str
    enable_purge_protection: builtins.bool
    enable_soft_delete: builtins.bool
    @property
    def initial_admin_object_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def network_acls(self) -> global___MHSMNetworkRuleSet: ...
    public_network_access: builtins.str
    soft_delete_retention_in_days: builtins.int
    tenant_id: builtins.str
    @property
    def sku(self) -> global___ManagedHsmSku: ...
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_h_s_ms_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedHSMsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        create_mode: builtins.str = ...,
        enable_purge_protection: builtins.bool = ...,
        enable_soft_delete: builtins.bool = ...,
        initial_admin_object_ids: collections.abc.Iterable[builtins.str] | None = ...,
        network_acls: global___MHSMNetworkRuleSet | None = ...,
        public_network_access: builtins.str = ...,
        soft_delete_retention_in_days: builtins.int = ...,
        tenant_id: builtins.str = ...,
        sku: global___ManagedHsmSku | None = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_h_s_ms_private_endpoint_connections: collections.abc.Iterable[global___ManagedHSMsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_acls", b"network_acls", "resource_info", b"resource_info", "sku", b"sku", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_mode", b"create_mode", "enable_purge_protection", b"enable_purge_protection", "enable_soft_delete", b"enable_soft_delete", "initial_admin_object_ids", b"initial_admin_object_ids", "location", b"location", "managed_h_s_ms_private_endpoint_connections", b"managed_h_s_ms_private_endpoint_connections", "name", b"name", "network_acls", b"network_acls", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "sku", b"sku", "soft_delete_retention_in_days", b"soft_delete_retention_in_days", "system_data", b"system_data", "tags", b"tags", "tenant_id", b"tenant_id"]) -> None: ...

global___ManagedHSMs = ManagedHSMs

@typing_extensions.final
class SystemData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_TYPE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_TYPE_FIELD_NUMBER: builtins.int
    created_at: builtins.str
    created_by: builtins.str
    created_by_type: builtins.str
    last_modified_at: builtins.str
    last_modified_by: builtins.str
    last_modified_by_type: builtins.str
    def __init__(
        self,
        *,
        created_at: builtins.str = ...,
        created_by: builtins.str = ...,
        created_by_type: builtins.str = ...,
        last_modified_at: builtins.str = ...,
        last_modified_by: builtins.str = ...,
        last_modified_by_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "created_by_type", b"created_by_type", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "last_modified_by_type", b"last_modified_by_type"]) -> None: ...

global___SystemData = SystemData

@typing_extensions.final
class ManagedHsmSku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    family: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        family: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["family", b"family", "name", b"name"]) -> None: ...

global___ManagedHsmSku = ManagedHsmSku

@typing_extensions.final
class MHSMNetworkRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYPASS_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    bypass: builtins.str
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MHSMIPRule]: ...
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MHSMVirtualNetworkRule]: ...
    def __init__(
        self,
        *,
        bypass: builtins.str = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___MHSMIPRule] | None = ...,
        virtual_network_rules: collections.abc.Iterable[global___MHSMVirtualNetworkRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass", b"bypass", "default_action", b"default_action", "ip_rules", b"ip_rules", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___MHSMNetworkRuleSet = MHSMNetworkRuleSet

@typing_extensions.final
class MHSMVirtualNetworkRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___MHSMVirtualNetworkRule = MHSMVirtualNetworkRule

@typing_extensions.final
class MHSMIPRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___MHSMIPRule = MHSMIPRule
